{% load i18n %}

<!-- request details modal -->
<div class="modal fade" id="srp-request-details" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <div class="modal-title fs-5">
                    {% translate "SRP request details" %}
                </div>

                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="{% translate 'Close' %}"></button>
            </div>

            <div class="modal-body"></div>

            <div class="modal-footer">
                <button id="modal-button-request-details-confirm" type="button" class="btn btn-secondary btn-sm" data-bs-dismiss="modal">
                    {% translate "Close" %}
                </button>
            </div>
        </div>
    </div>
</div>
